@@ -105,22 +105,24 @@ void MainWindow::rom_exec(){
             }
         }
 
-        ui->pushButton->setEnabled(false);
-        ui->pushButton_2->setEnabled(false);
-        QProcess *myProcess = new QProcess();
-        myProcess->setWorkingDirectory("/home/user/");
-        connect(myProcess, SIGNAL(finished(int)), this, SLOT(process_finished(int)));
+        if (myProcess == NULL){
+            ui->pushButton->setEnabled(false);
+            ui->pushButton_2->setEnabled(false);
+            myProcess = new QProcess(this);
+            myProcess->setWorkingDirectory("/home/user/");
+            connect(myProcess, SIGNAL(finished(int)), this, SLOT(process_finished(int)));
 
-        QStringList args=current_config;
-        //args<<roms.value(ui->listWidget->currentRow())<<"-save_name"<<(ui->listWidget->currentItem()->text());
-        args<<roms.value(ui->listWidget->currentRow());
-        qDebug (QString("%1 %2").arg("/opt/maemo/usr/games/"+current_core).arg(args.join(" ")).toAscii());
-        /*if (!myProcess->startDetached("/opt/maemo/usr/games/"+current_core, args,"/home/user/"))
-            process_finished(-1);*/
-        myProcess->start("/opt/maemo/usr/games/"+current_core, args);
-        if (!myProcess->waitForStarted(10000)){
-            qDebug() << "Failed to start process.";
-            process_finished(-1);
+            QStringList args=current_config;
+            //args<<roms.value(ui->listWidget->currentRow())<<"-save_name"<<(ui->listWidget->currentItem()->text());
+            args<<roms.value(ui->listWidget->currentRow());
+            qDebug (QString("%1 %2").arg("/opt/maemo/usr/games/"+current_core).arg(args.join(" ")).toAscii());
+            /*if (!myProcess->startDetached("/opt/maemo/usr/games/"+current_core, args,"/home/user/"))
+                process_finished(-1);*/
+            myProcess->start("/opt/maemo/usr/games/"+current_core, args);
+            if (!myProcess->waitForStarted(10000)){
+                qDebug() << "Failed to start process.";
+                process_finished(-1);
+            }
         }
     }
 }
@@ -129,6 +131,8 @@ void MainWindow::process_finished(int)
 {
     ui->pushButton->setEnabled(true);
     ui->pushButton_2->setEnabled(true);
+    myProcess->deleteLater();
+    myProcess = NULL;
 }
 
 void MainWindow::currentRowChanged ( int  ){
@@ -223,8 +227,11 @@ void MainWindow::set_rom_dir()
         rom_path=dir;
         settings->setValue("rom_path",rom_path);
         settings->sync();
-        if (settings->status() != QSettings::NoError)
-            qDebug("Can't save gui config, permission error?");
+        if (settings->status() != QSettings::NoError){
+            QMessageBox msg;
+            msg.setText("Can't save gui config, permission error?");
+            msg.exec();
+        }
         lbl1->setText(rom_path);
         get_roms();
     }
@@ -238,8 +245,11 @@ void MainWindow::set_bios_dir()
         if (bios_path.right(1)!="/")bios_path+="/";
         settings->setValue("bios_path",bios_path);
         settings->sync();
-        if (settings->status() != QSettings::NoError)
-            qDebug("Can't save gui config, permission error?");
+        if (settings->status() != QSettings::NoError){
+            QMessageBox msg;
+            msg.setText("Can't save gui config, permission error?");
+            msg.exec();
+        }
         lbl2->setText(bios_path);
     }
 }
